============================================
omnium - Output Management for UM. In alpha.
============================================

* Designed to fit into rose/cylc workflow
* Also easy to use as a standalone utility.
* Allows easy adding of new analyzers to workflow.
* Conversion from fields files to NetCDF4.
* Sync'ing from work computer to local mirror.
* Data visualization with 2D and 3D displays.

Dependencies
============

* iris
* pyqtgraph (data visualization)
* rsync
